<?php

namespace Neuron\Person\Controller;

use Neuron\Person\Skill\Types;
use Neuron\Person\Skill\Type;
use Neuron\Person\Skill;
use Neuron\Generic\Result;

class SkillType extends \Neuron\Person\Controller
{
	protected function getView($name, $variables = array())
	{
		/* default layout & view prefix */
		$layout = 'neuron/person/layout/';
		$prefix = 'neuron/person';
		if (!class_exists('Neuron\Application\Framework\Entity')) {
			/* libraries */
			$this->using('jquery', null)
				->using(
					'bootstrap-4',
					null,
					array(
						'https://ajax.googleapis.com/ajax/libs/jquery/3.3.1/jquery.min.js',
						'https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js',
						'https://maxcdn.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css',
						'https://maxcdn.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js'
					)
				)
				->using('fontawesome', null);
		}
		/* get layout n view prefix from config */
		$config = $this->getConfig();
		if (isset($config['person'])) {
			$config = $config['person'];
			$layout = isset($config['formlayout']) ? $config['formlayout'] : $layout;
			$prefix = isset($config['viewprefix']) ? $config['viewprefix'] : $prefix;
		}

		$this->using('nAlert', 9999999);

		/* set layout and view */
		$this->layout($layout);
		$view = new \Zend\View\Model\ViewModel($variables);
		$view->setTemplate($prefix . '/' . strtolower($name));

		return $view;
	}

	public function listAction()
	{
		$layout = $this->layout();
        $layout->setVariables(['current' => 'Parameters Type Skill']);

		$this->using('datatable', 19, array(
			'https://cdn.datatables.net/1.10.19/js/jquery.dataTables.min.js',
			'https://cdn.datatables.net/1.10.19/js/dataTables.bootstrap4.min.js',
			'https://cdn.datatables.net/1.10.19/css/dataTables.bootstrap4.min.css'
		));
		$this->usingJs('bootbox',21,  array(
			'https://cdnjs.cloudflare.com/ajax/libs/bootbox.js/4.4.0/bootbox.min.js'
		));

		$this->using('p-loading', 22);
		$this->usingJs('moment', 23, array(
			'https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.29.1/moment.min.js'
		));
		$this->using('bootstrap-datepicker', 24);
		$this->using('select2', 26, array(
			'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.10/js/select2.min.js',
			/* ini load sesuai bahasa dari session */
			'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.10/js/i18n/id.js',
			/**/
			'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.10/css/select2.min.css',
			'https://cdn.jsdelivr.net/npm/@ttskch/select2-bootstrap4-theme@1.3.2/dist/select2-bootstrap4.min.css',
		));
		$this->using('generic', 30);
		$this->using('jquery.validate', 31, array(
			"https://cdnjs.cloudflare.com/ajax/libs/jquery-validate/1.19.2/jquery.validate.min.js",
			"https://cdnjs.cloudflare.com/ajax/libs/jquery-validate/1.19.2/additional-methods.min.js"
		));

		$title 	= $this->translate("Parameters Type Skill");

		return $this->getView('skill/type/list', get_defined_vars());
	}

	public function loadListAction()
	{
        $post	= $this->getPostParams();
        
        $skill  = new Types(Type\Storage::factory($this->getDb(),$this->getConfig()));
        if (isset($post['start']) && isset($post['length'])) {
            $params = array(
                'page' 		=> ($post['start'] + $post['length']) / $post['length'],
                'records' 	=> $post['length'],
                'order' 	=> $post['order'],
                'columns' 	=> $post['columns'],
            );

            $keyword 	= $post['search']['value'];
            $datatable 	= true;
            if ($post['length'] == -1) {
                $mode 	= Type\Storage::LIST_ALL;
            } else {
                $mode 	= Type\Storage::LISTBY_PAGE;
            }
        } else {
            $post 		= $this->getREST()->getParameters();
            $params 	= is_array(@$post['additional']) ? @$post['additional'] : array();
            $keyword 	= @$post['keyword'];
            $mode 		= isset($post['mode'])? $post['mode']: Type\Storage::LIST_ALL;
            $datatable 	= false;
        }
        
        $result = $skill->load($keyword, $mode, $params);
        
        if ($datatable) {
            if ($result->code == $result::CODE_SUCCESS) {
                $listData['draw'] = $post['draw'];
                $listData['recordsTotal'] = $result->data['countTotal'];
                $listData['recordsFiltered'] = $result->data['countTotal'];
                $listData['data'] = @$result->data['list'];
            } else {
                $listData['draw'] = $post['draw'];
                $listData['recordsTotal'] = 0;
                $listData['recrodsFiltered'] = 0;
                $listData['data'] = array();
            }
            
            return $this->getOutput(json_encode($listData));
        }

  		return $this->getRest()->getResponse($result);
    }

	public function saveAction(){
		$data       	= $this->getRequest()->getPost();
        if (empty($data)) {
            $data   	= $this->getREST()->getParameters();            
        }

		$result			= new Result();

		$data['skill_code']	= strtoupper(str_replace(' ', '_', $data['skill_name']));
		$data['skill_name']	= strtoupper($data['skill_name']);
        
		$skill 			= new Type(Type\Storage::factory($this->getDb(), $this->getConfig()));
		$skill->load($data['skill_code']);
		
		if ($skill->skill_code) {
			$result->info 	= $this->translate('Skill type already exists');
			$result->code 	= 401;
			
			return $this->getREST()->getResponse($result);
		} 

		$result 		= $skill->create($data);
		$result->info 	= $this->translate($result->info);

		return $this->getREST()->getResponse($result);
	}

	public function deleteAction(){
		$data       	= $this->getRequest()->getPost();
        if (empty($data)) {
            $data   	= $this->getREST()->getParameters();            
        }
		
		$result			= new Result();

		$skill 			= new Type(Type\Storage::factory($this->getDb(), $this->getConfig()));
		$mSkill			= new Skill(Skill\Storage::factory($this->getDb(), $this->getConfig()));
		$mSkill->load($data['code'], Skill\Storage::LOADBY_CODE, null);
		
		if ($mSkill->skill_code) {
			$result->code = 401;
			$result->info = $this->translate('skill type already mapped');

			return $this->getREST()->getResponse($result);
		}

		$result 		= $skill->delete($data['skill_type_id']);
		$result->info 	= $this->translate($result->info);

		return $this->getREST()->getResponse($result);
	}
}

